@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *)
 
-open Ocsigen_pervasives
+open Ocsigen_lib
 
 exception Dynlink_error of string * exn
 exception Findlib_error of string * exn
